nodejs: A JavaScript runtime built on Chrome's V8 JavaScript engine
===================================================================

Description
-----------

Node.js® is a JavaScript runtime built on Chrome's V8 JavaScript engine.

It is installed into an isolated nodeenv.

License
-------

MIT License

Upstream Contact
----------------

Home page: https://nodejs.org/

Dependencies
------------

- nodeenv
